km3pipe.dataclasses.ArrayTaco
=============================

.. currentmodule:: km3pipe.dataclasses

.. autoclass:: ArrayTaco

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ArrayTaco.__init__
      ~ArrayTaco.deserialise
      ~ArrayTaco.from_dict
      ~ArrayTaco.serialise
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~ArrayTaco.dtype
   
   